import { asyncRoutes, constantRoutes } from '@/router'

/**
 * Use meta.role to determine if the current user has permission
 * @param roles
 * @param route
 */
function hasPermission(roles, route) {
  if (route.meta && route.meta.roles) {
    return roles.some(role => route.meta.roles.includes(role))
  } else {
    return true
  }
}

/**
 * Filter asynchronous routing tables by recursion
 * @param routes asyncRoutes
 * @param roles
 */
export function filterAsyncRoutes(routes, roles) {
  const res = []
  routes.forEach(route => {
    const tmp = { ...route }
    if (hasPermission(roles, tmp)) {
      if (tmp.children) {
        tmp.children = filterAsyncRoutes(tmp.children, roles)
      }
      res.push(tmp)
    }
  })
  return res
}

const state = {
  routes: [],
  addRoutes: []
}

const mutations = {
  SET_ROUTES: (state, routes) => {
    state.addRoutes = routes
    state.routes = constantRoutes.concat(routes)
  }
}

const actions = {
  generateRoutes({ commit }, authList) {//authList roles
    return new Promise(resolve => {
      /* let accessedRoutes
      if (roles.includes('admin')) {
        accessedRoutes = asyncRoutes || []
      } else {
        accessedRoutes = filterAsyncRoutes(asyncRoutes, roles)
      } */
      let accessedRoutes=[];
      if (authList != undefined) {
        let tempRoutes = asyncRoutes.filter(o => {
          return authList.filter(u => u.parent_id == o.type).length > 0;
        });
        tempRoutes = tempRoutes.map((res) => {
          if (res.children && res.children.length > 0) { // 检查 res.children 是否存在
            res.children = res.children.filter(o => authList.filter(u => u.code == o.name).length > 0);
          }
          return res;
        });

        console.log("tempRoutes", tempRoutes);
        accessedRoutes = tempRoutes;
        accessedRoutes.push({ path: '*', redirect: '/404', hidden: true });
      }
      commit('SET_ROUTES', accessedRoutes)
      console.log(accessedRoutes);
      resolve(accessedRoutes)
    })
  }
}

export default {
  namespaced: true,
  state,
  mutations,
  actions
}
