import { getToken, setToken, removeToken } from '@/utils/auth'
import router, { resetRouter } from '@/router'

import {userLogin,getCurrentUserInfo,userLogout} from "@/api/api"
const state = {
  token: getToken(),
  name: '',
  email:'',
  avatar: '',
  introduction: '',
  roles: [],
  roleInfo:{},
  authList:[],
  id:''
}

const mutations = {
  SET_TOKEN: (state, token) => {
    state.token = token
  },
  SET_INTRODUCTION: (state, introduction) => {
    state.introduction = introduction
  },
  SET_NAME: (state, name) => {
    state.name = name
  },
  SET_EMAIL: (state, email) => {
    state.email = email
  },
  SET_AVATAR: (state, avatar) => {
    state.avatar = avatar
  },
  SET_ROLES: (state, roles) => {
    state.roles = roles
  },
  SET_ROLE_INFO:(state,roleInfo)=>{
    state.roleInfo=roleInfo;
  },
  SET_AUTH_LIST:(state,authList)=>{
    state.authList=authList;
  },
  SET_ID:(state,id)=>{
    state.id=id;
  }
}

const actions = {
  // user login
  login({ commit }, userInfo) {
    const { username, password } = userInfo
    return new Promise((resolve, reject) => {
      userLogin({ username: username.trim(), password: password }).then(response => {
        const { data } = response
        commit('SET_TOKEN', data.token)
        setToken(data.token)
        resolve()
      }).catch(error => {
        reject(error)
      })
    })
  },

  // get user info
  getInfo({ commit, state }) {
    return new Promise((resolve, reject) => {
      getCurrentUserInfo({name:'name'}).then(response => {
        const { data } = response

        if (!data) {
          reject('Verification failed, please Login again.')
        }
        const { roles, username,email,realName,avatar, introduction,roleInfo,authList,id } = data
        if (!roles || roles.length <= 0) {
            reject('getInfo: roles must be a non-null array!')
        }



        commit('SET_ROLE_INFO',roleInfo)
        commit('SET_ROLES', roles)
        commit('SET_NAME', realName)
        commit('SET_EMAIL', email)
        commit('SET_AVATAR', avatar)
        commit('SET_AUTH_LIST', authList)
        commit('SET_INTRODUCTION', introduction)
        commit('SET_ID', id)

        resolve(data)
      }).catch(error => {
        reject(error)
      })
    })
  },

  // user logout
  logout({ commit, state, dispatch }) {
    return new Promise((resolve, reject) => {
      userLogout(state.token).then(() => {
        commit('SET_TOKEN', '')
        commit('SET_ROLES', [])
        removeToken()
        resetRouter()
        // reset visited views and cached views
        // to fixed https://github.com/PanJiaChen/vue-element-admin/issues/2485
        dispatch('tagsView/delAllViews', null, { root: true })

        resolve()
      }).catch(error => {
        reject(error)
      })
    })
  },

  // remove token
  resetToken({ commit }) {
    return new Promise(resolve => {
      commit('SET_TOKEN', '')
      commit('SET_ROLES', [])
      removeToken()
      resolve()
    })
  },

  // dynamically modify permissions
  async changeRoles({ commit, dispatch }, role) {
    const token = role + '-token'
    commit('SET_TOKEN', token)
    setToken(token)
    const { roles,authList } = await dispatch('getInfo')
    resetRouter()
    // generate accessible routes map based on roles
    const accessRoutes = await dispatch('permission/generateRoutes', roles, authList)
    // dynamically add accessible routes
    router.addRoutes(accessRoutes)
    // reset visited views and cached views
    dispatch('tagsView/delAllViews', null, { root: true })
  }
}

export default {
  namespaced: true,
  state,
  mutations,
  actions
}
